==> sale-3.2.0.jar: revenue/sqls/revenue/BizOperation/BankReconciliation/bankPayment.sql <==
select s.*,ui.f_userinfo_code from (
select
	F_SERIAL_ID,SELL_USER_ID,F_COLLECTION,F_USER_NAME,f_operate_date,f_state,F_BANK_NAME,bankname,
	F_ALIAS,F_TOTAL_CHARGE,BANK_USER_ID,F_TRADE_NUMBER,F_TRADE_DATE,maxid,
	 { entity.findDialect() == $SqlServer$: $isnull$,$NVL$}(b.f_userinfo_id,s.f_userinfo_id) f_userinfo_id,b.f_userfiles_id,
	(case
		when s.f_operate_date is null then b.f_trade_date
		when b.f_trade_date is null then s.f_operate_date
		else s.f_operate_date
	 end) delivery_date,
	(CASE
		 WHEN s.f_collection = b.F_TOTAL_CHARGE  THEN '对账成功'
		 WHEN s.f_collection != b.F_TOTAL_CHARGE THEN '对账金额错误'
		 WHEN b.f_trade_number IS NULL THEN '燃气方单方面账单'
		 WHEN s.f_serial_id IS NULL  THEN '银行方单方面账单'
		 ELSE '匹配无效'
	 END) msg

from
	(SELECT id as sellid,f_bank_name as bankname,f_serial_id,f_user_id sell_user_id,f_collection,f_user_name,f_operate_date,f_state,f_userinfo_id
from t_sellinggas where f_state = '有效' and f_payment like '%银行%') s
LEFT JOIN ( SELECT MAX ( id ) maxid, f_userfiles_id FROM t_sellinggas WHERE f_state = '有效' GROUP BY f_userfiles_id ) maxsell ON s.sellid= maxsell.maxid
full outer join
(select bp.f_bank_name,bp.f_alias,bp.f_gas_fee/100 F_TOTAL_CHARGE,bp.f_user_id bank_user_id,bp.f_trade_number,bp.f_trade_date,uf.f_userfiles_id,uf.f_userinfo_id
from t_bank_payment bp left join (select * from t_userfiles where f_table_state='正常')uf on bp.f_userfiles_id=uf.f_userfiles_id) b
on s.f_serial_id = b.f_trade_number
) s
left join t_userinfo ui on s.f_userinfo_id=ui.f_userinfo_id
where {condition}
order by {orderitem}

==> sale-3.5.3.jar: revenue/sqls/revenue/BizOperation/BankReconciliation/bankPayment.sql <==
select s.*,ui.f_userinfo_code from (
select
	F_SERIAL_ID,SELL_USER_ID,F_COLLECTION,F_USER_NAME,f_operate_date,f_state,F_BANK_NAME,bankname,
	F_ALIAS,F_TOTAL_CHARGE,BANK_USER_ID,F_TRADE_NUMBER,F_TRADE_DATE,maxid,
	 { entity.findDialect() == $SqlServer$: $isnull$,$NVL$}(b.f_userinfo_id,s.f_userinfo_id) f_userinfo_id,b.f_userfiles_id,
	(case
		when s.f_operate_date is null then b.f_trade_date
		when b.f_trade_date is null then s.f_operate_date
		else s.f_operate_date
	 end) delivery_date,
	(CASE
		 WHEN s.f_collection = b.F_TOTAL_CHARGE  THEN '对账成功'
		 WHEN s.f_collection != b.F_TOTAL_CHARGE THEN '对账金额错误'
		 WHEN b.f_trade_number IS NULL THEN '燃气方单方面账单'
		 WHEN s.f_serial_id IS NULL  THEN '银行方单方面账单'
		 ELSE '匹配无效'
	 END) msg

from
	(SELECT id as sellid,f_bank_name as bankname,f_serial_id,f_user_id sell_user_id,f_collection,f_user_name,f_operate_date,f_state,f_userinfo_id
from t_sellinggas where f_state = '有效' and (f_payment like '%银行%'
    or f_payment like '%pos聚合支付%')
) s
LEFT JOIN ( SELECT MAX ( id ) maxid, f_userfiles_id FROM t_sellinggas WHERE f_state = '有效' GROUP BY f_userfiles_id ) maxsell ON s.sellid= maxsell.maxid
full outer join
(select bp.f_bank_name,bp.f_alias,bp.f_gas_fee/100 F_TOTAL_CHARGE,bp.f_user_id bank_user_id,bp.f_trade_number,bp.f_trade_date,uf.f_userfiles_id,uf.f_userinfo_id
from t_bank_payment bp left join (select * from t_userfiles where f_table_state='正常')uf on bp.f_userfiles_id=uf.f_userfiles_id) b
on s.f_serial_id = b.f_trade_number
) s
left join t_userinfo ui on s.f_userinfo_id=ui.f_userinfo_id
where {condition}
order by {orderitem}
